@@ -1,6 +1,9 @@
 import numpy as np
-from gemmi import SpaceGroup,GroupOps
+from gemmi import GroupOps, SpaceGroup
+
 import reciprocalspaceship as rs
+from reciprocalspaceship.decorators import spacegroupify
+
 
 def to_structurefactor(sfamps, phases):
     """
@@ -23,7 +26,8 @@ def to_structurefactor(sfamps, phases):
         sfamps = sfamps.to_numpy()
     if isinstance(phases, rs.DataSeries):
         phases = phases.to_numpy()
-    return sfamps*np.exp(1j*np.deg2rad(phases))
+    return sfamps * np.exp(1j * np.deg2rad(phases))
+
 
 def from_structurefactor(sfs):
     """
@@ -38,16 +42,20 @@ def from_structurefactor(sfs):
     Returns
     -------
     (sf, phase) : tuple of DataSeries
-        Tuple of DataSeries for the structure factor amplitudes and 
+        Tuple of DataSeries for the structure factor amplitudes and
         phases corresponding to the provided complex structure factors
     """
     index = None
     if isinstance(sfs, rs.DataSeries):
         index = sfs.index
     sf = rs.DataSeries(np.abs(sfs), index=index, name="F").astype("SFAmplitude")
-    phase = rs.DataSeries(np.angle(sfs, deg=True), index=index, name="Phi").astype("Phase")
+    phase = rs.DataSeries(np.angle(sfs, deg=True), index=index, name="Phi").astype(
+        "Phase"
+    )
     return sf, phase
 
+
+@spacegroupify
 def compute_structurefactor_multiplicity(H, sg, include_centering=True):
     """
     Compute the multiplicity of each reflection in ``H``.
@@ -56,11 +64,11 @@ def compute_structurefactor_multiplicity(H, sg, include_centering=True):
     ----------
     H : array
         n x 3 array of Miller indices
-    spacegroup : gemmi.SpaceGroup, gemmi.GroupOps
+    spacegroup : str, int, gemmi.SpaceGroup
         The space group to identify the asymmetric unit
     include_centering : bool
         Whether or not to include the multiplicity inherent in the lattice centering.
-        The default is True. If False, the minimum value of epsilon will be 1 
+        The default is True. If False, the minimum value of epsilon will be 1
         irrespective of space group.
 
     Returns
@@ -69,33 +77,28 @@ def compute_structurefactor_multiplicity(H, sg, include_centering=True):
         an array of length n containing the multiplicity
         of each hkl.
     """
-    if isinstance(sg, SpaceGroup):
-        group_ops = sg.operations()
-    elif isinstance(sg, GroupOps):
-        group_ops = sg
-    else:
-        raise ValueError(f"gemmi.SpaceGroup or gemmi.GroupOps expected for parameter sg. "
-                         f"Received object of type: ({type(sg)}) instead.")
-
+    group_ops = sg.operations()
     is_centric = group_ops.is_centric()
 
-    #Lookup based on centering is equivalent to counting the number of translational
-    #centering operations. Using the number of operations has proven more robust. 
+    # Lookup based on centering is equivalent to counting the number of translational
+    # centering operations. Using the number of operations has proven more robust.
     if include_centering:
-        L = (1 + is_centric)
+        L = 1 + is_centric
     else:
         L = len(group_ops.cen_ops)
-        L = L*(1 + is_centric)
+        L = L * (1 + is_centric)
 
     eps = np.zeros(len(H))
     for op in group_ops:
         h = rs.utils.apply_to_hkl(H, op)
         if is_centric:
-            eps += np.all(h==H, 1) | np.all(h==-H, 1)
+            eps += np.all(h == H, 1) | np.all(h == -H, 1)
         else:
-            eps += np.all(h==H, 1) 
-    return eps/L
+            eps += np.all(h == H, 1)
+    return eps / L
 
+
+@spacegroupify
 def is_centric(H, spacegroup):
     """
     Determine if Miller indices are centric in a given spacegroup
@@ -104,7 +107,7 @@ def is_centric(H, spacegroup):
     ----------
     H : array
         n x 3 array of Miller indices
-    spacegroup : gemmi.SpaceGroup, gemmi.GroupOps
+    spacegroup : str, int, gemmi.SpaceGroup
         The space group in which to classify centrics
 
     Returns
@@ -112,28 +115,23 @@ def is_centric(H, spacegroup):
     centric : array
         Boolean arreay with len(centric) == np.shape(H)[0] == n
     """
-    if isinstance(spacegroup, SpaceGroup):
-        group_ops = spacegroup.operations()
-    elif isinstance(spacegroup, GroupOps):
-        group_ops = spacegroup
-    else:
-        raise ValueError(f"gemmi.SpaceGroup or gemmi.GroupOps expected for parameter sg. "
-                         f"Received object of type: ({type(spacegroup)}) instead.")
-
+    group_ops = spacegroup.operations()
     hkl, inverse = np.unique(H, axis=0, return_inverse=True)
     centric = group_ops.centric_flag_array(hkl)
     return centric[inverse]
 
+
+@spacegroupify
 def is_absent(H, spacegroup):
     """
-    Determine if Miller indices are systematically absent in a given 
+    Determine if Miller indices are systematically absent in a given
     spacegroup.
 
     Parameters
     ----------
     H : array
         n x 3 array of Miller indices
-    spacegroup : gemmi.SpaceGroup, gemmi.GroupOps
+    spacegroup : str, int, gemmi.SpaceGroup
         The space group in which to classify systematic absences
 
     Returns
@@ -141,14 +139,4 @@ def is_absent(H, spacegroup):
     absent : array
         Boolean array of length n. absent[i] == True if H[i] is systematically absent in sg.
     """
-    if isinstance(spacegroup, SpaceGroup):
-        group_ops = spacegroup.operations()
-    elif isinstance(spacegroup, GroupOps):
-        group_ops = spacegroup
-    else:
-        raise ValueError(f"gemmi.SpaceGroup or gemmi.GroupOps expected for parameter sg. "
-                         f"Received object of type: ({type(spacegroup)}) instead.")
-
-
-    return group_ops.systematic_absences(H)
-
+    return spacegroup.operations().systematic_absences(H)
